@@ -5,7 +5,7 @@
 # ScanCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/skeleton for support or download.
+# See https://github.com/aboutcode-org/skeleton for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 import email
@@ -28,8 +28,8 @@ import saneyaml
 from commoncode import fileutils
 from commoncode.hash import multi_checksums
 from commoncode.text import python_safe_name
-from packaging import tags as packaging_tags
-from packaging import version as packaging_version
+from packvers import tags as packaging_tags
+from packvers import version as packaging_version
 
 import utils_pip_compatibility_tags
 
@@ -115,14 +115,14 @@ TRACE_DEEP = False
 TRACE_ULTRA_DEEP = False
 
 # Supported environments
-PYTHON_VERSIONS = "36", "37", "38", "39", "310"
+PYTHON_VERSIONS = "310", "311", "312", "313", "314"
 
 PYTHON_DOT_VERSIONS_BY_VER = {
-    "36": "3.6",
-    "37": "3.7",
-    "38": "3.8",
-    "39": "3.9",
     "310": "3.10",
+    "311": "3.11",
+    "312": "3.12",
+    "313": "3.13",
+    "314": "3.14",
 }
 
 
@@ -134,11 +134,11 @@ def get_python_dot_version(version):
 
 
 ABIS_BY_PYTHON_VERSION = {
-    "36": ["cp36", "cp36m", "abi3"],
-    "37": ["cp37", "cp37m", "abi3"],
-    "38": ["cp38", "cp38m", "abi3"],
-    "39": ["cp39", "cp39m", "abi3"],
     "310": ["cp310", "cp310m", "abi3"],
+    "311": ["cp311", "cp311m", "abi3"],
+    "312": ["cp312", "cp312m", "abi3"],
+    "313": ["cp313", "cp313m", "abi3"],
+    "314": ["cp314", "cp314m", "abi3"],
 }
 
 PLATFORMS_BY_OS = {
@@ -311,6 +311,7 @@ def download_sdist(name, version, dest_dir=THIRDPARTY_DIR, repos=tuple()):
 
     return fetched_sdist_filename
 
+
 ################################################################################
 #
 # Core models
@@ -356,7 +357,6 @@ class NameVer:
 
 @attr.attributes
 class Distribution(NameVer):
-
     # field names that can be updated from another Distribution or mapping
     updatable_fields = [
         "license_expression",
@@ -911,7 +911,7 @@ class Distribution(NameVer):
         declared_license = [raw_data["License"]] + [
             c for c in classifiers if c.startswith("License")
         ]
-        license_expression = compute_normalized_license_expression(declared_license)
+        license_expression = get_license_expression(declared_license)
         other_classifiers = [c for c in classifiers if not c.startswith("License")]
 
         holder = raw_data["Author"]
@@ -1064,16 +1064,16 @@ def get_sdist_name_ver_ext(filename):
     if version.isalpha():
         return False
 
-    # non-pep 440 version    
+    # non-pep 440 version
     if "-" in version:
         return False
 
-    # single version    
+    # single version
     if version.isdigit() and len(version) == 1:
         return False
 
-    # r1 version    
-    if len(version) == 2 and version[0]=="r" and version[1].isdigit():
+    # r1 version
+    if len(version) == 2 and version[0] == "r" and version[1].isdigit():
         return False
 
     # dotless version (but calver is OK)
@@ -1092,7 +1092,6 @@ def get_sdist_name_ver_ext(filename):
 
 @attr.attributes
 class Sdist(Distribution):
-
     extension = attr.ib(
         repr=False,
         type=str,
@@ -1130,7 +1129,6 @@ class Sdist(Distribution):
 
 @attr.attributes
 class Wheel(Distribution):
-
     """
     Represents a wheel file.
 
@@ -1336,10 +1334,10 @@ class PypiPackage(NameVer):
 
         For example:
         >>> w1 = Wheel(name='bitarray', version='0.8.1', build='',
-        ...    python_versions=['cp36'], abis=['cp36m'],
+        ...    python_versions=['cp38'], abis=['cp38m'],
         ...    platforms=['linux_x86_64'])
         >>> w2 = Wheel(name='bitarray', version='0.8.1', build='',
-        ...    python_versions=['cp36'], abis=['cp36m'],
+        ...    python_versions=['cp38'], abis=['cp38m'],
         ...    platforms=['macosx_10_9_x86_64', 'macosx_10_10_x86_64'])
         >>> sd = Sdist(name='bitarray', version='0.8.1')
         >>> package = PypiPackage.package_from_dists(dists=[w1, w2, sd])
@@ -1588,6 +1586,7 @@ class Environment:
             )
         )
 
+
 ################################################################################
 #
 # PyPI repo and link index for package wheels and sources
@@ -1629,7 +1628,9 @@ class PypiSimpleRepository:
     use_cached_index = attr.ib(
         type=bool,
         default=False,
-        metadata=dict(help="If True, use any existing on-disk cached PyPI index files. Otherwise, fetch and cache."),
+        metadata=dict(
+            help="If True, use any existing on-disk cached PyPI index files. Otherwise, fetch and cache."
+        ),
     )
 
     def _get_package_versions_map(self, name):
@@ -1674,6 +1675,7 @@ class PypiSimpleRepository:
         """
         if not version:
             versions = list(self._get_package_versions_map(name).values())
+            # return the latest version
             return versions and versions[-1]
         else:
             return self._get_package_versions_map(name).get(version)
@@ -1724,7 +1726,9 @@ class LinksRepository:
     use_cached_index = attr.ib(
         type=bool,
         default=False,
-        metadata=dict(help="If True, use any existing on-disk cached index files. Otherwise, fetch and cache."),
+        metadata=dict(
+            help="If True, use any existing on-disk cached index files. Otherwise, fetch and cache."
+        ),
     )
 
     def __attrs_post_init__(self):
@@ -1790,6 +1794,7 @@ class LinksRepository:
             _LINKS_REPO[url] = cls(url=url, use_cached_index=use_cached_index)
         return _LINKS_REPO[url]
 
+
 ################################################################################
 # Globals for remote repos to be lazily created and cached on first use for the
 # life of the session together with some convenience functions.
@@ -1803,6 +1808,7 @@ def get_local_packages(directory=THIRDPARTY_DIR):
     """
     return list(PypiPackage.packages_from_dir(directory=directory))
 
+
 ################################################################################
 #
 # Basic file and URL-based operations using a persistent file-based Cache
@@ -1953,6 +1959,7 @@ def fetch_and_save(
         fo.write(content)
     return content
 
+
 ################################################################################
 #
 # Functions to update or fetch ABOUT and license files
@@ -2051,7 +2058,9 @@ def fetch_abouts_and_licenses(dest_dir=THIRDPARTY_DIR, use_cached_index=False):
                 # if has key data we may look to improve later, but we can move on
                 if local_dist.has_key_metadata():
                     local_dist.save_about_and_notice_files(dest_dir=dest_dir)
-                    local_dist.fetch_license_files(dest_dir=dest_dir, use_cached_index=use_cached_index)
+                    local_dist.fetch_license_files(
+                        dest_dir=dest_dir, use_cached_index=use_cached_index
+                    )
                     continue
 
             # lets try to fetch remotely
@@ -2089,7 +2098,9 @@ def fetch_abouts_and_licenses(dest_dir=THIRDPARTY_DIR, use_cached_index=False):
                 # if has key data we may look to improve later, but we can move on
                 if local_dist.has_key_metadata():
                     local_dist.save_about_and_notice_files(dest_dir=dest_dir)
-                    local_dist.fetch_license_files(dest_dir=dest_dir, use_cached_index=use_cached_index)
+                    local_dist.fetch_license_files(
+                        dest_dir=dest_dir, use_cached_index=use_cached_index
+                    )
                     continue
 
             # try to get data from pkginfo (no license though)
@@ -2107,6 +2118,7 @@ def fetch_abouts_and_licenses(dest_dir=THIRDPARTY_DIR, use_cached_index=False):
                 lic_errs = "\n".join(lic_errs)
                 print(f"Failed to fetch some licenses:: {lic_errs}")
 
+
 ################################################################################
 #
 # Functions to build new Python wheels including native on multiple OSes
@@ -2124,7 +2136,6 @@ def call(args, verbose=TRACE):
     with subprocess.Popen(
         args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, encoding="utf-8"
     ) as process:
-
         stdouts = []
         while True:
             line = process.stdout.readline()
@@ -2210,6 +2221,7 @@ def download_wheels_with_pip(
     downloaded = existing ^ set(os.listdir(dest_dir))
     return sorted(downloaded), error
 
+
 ################################################################################
 #
 # Functions to check for problems
@@ -2258,16 +2270,16 @@ def find_problems(
     check_about(dest_dir=dest_dir)
 
 
-def compute_normalized_license_expression(declared_licenses):
+def get_license_expression(declared_licenses):
     """
     Return a normalized license expression or None.
     """
     if not declared_licenses:
         return
     try:
-        from packagedcode import pypi
+        from packagedcode.licensing import get_only_expression_from_extracted_license
 
-        return pypi.compute_normalized_license(declared_licenses)
+        return get_only_expression_from_extracted_license(declared_licenses)
     except ImportError:
         # Scancode is not installed, clean and join all the licenses
         lics = [python_safe_name(l).lower() for l in declared_licenses]
