@@ -3,7 +3,7 @@
 # ScanCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0 AND MIT
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/typecode for support or download.
+# See https://github.com/aboutcode-org/typecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 # This code was in part derived from the python-magic library:
@@ -59,7 +59,8 @@ if TRACE:
     logger.setLevel(logging.DEBUG)
 
     def logger_debug(*args):
-        return logger.debug(' '.join(isinstance(a, str) and a or repr(a) for a in args))
+        return logger.debug(" ".join(isinstance(a, str) and a or repr(a) for a in args))
+
 
 #
 # Cached detectors
@@ -79,11 +80,11 @@ DETECT_MIME = MAGIC_NONE | MAGIC_MIME
 DETECT_ENC = MAGIC_NONE | MAGIC_MIME | MAGIC_MIME_ENCODING
 
 # keys for plugin-provided locations
-TYPECODE_LIBMAGIC_DLL = 'typecode.libmagic.dll'
-TYPECODE_LIBMAGIC_DB = 'typecode.libmagic.db'
+TYPECODE_LIBMAGIC_DLL = "typecode.libmagic.dll"
+TYPECODE_LIBMAGIC_DB = "typecode.libmagic.db"
 
-TYPECODE_LIBMAGIC_PATH_ENVVAR = 'TYPECODE_LIBMAGIC_PATH'
-TYPECODE_LIBMAGIC_DB_PATH_ENVVAR = 'TYPECODE_LIBMAGIC_DB_PATH'
+TYPECODE_LIBMAGIC_PATH_ENVVAR = "TYPECODE_LIBMAGIC_PATH"
+TYPECODE_LIBMAGIC_DB_PATH_ENVVAR = "TYPECODE_LIBMAGIC_DB_PATH"
 
 if TRACE:
 
@@ -93,7 +94,7 @@ if TRACE:
 else:
 
     def file_type(location):
-        """"
+        """ "
         Return the detected filetype for file at `location` or an empty string if
         nothing found or an error occurred.
         """
@@ -101,7 +102,7 @@ else:
             return _detect(location, DETECT_TYPE)
         except:
             # TODO: log errors
-            return ''
+            return ""
 
 
 class NoMagicLibError(Exception):
@@ -118,12 +119,12 @@ def load_lib_failover():
     libmagic = None
     # Let's try to find magic or magic1
     dll = (
-        ctypes.util.find_library('magic')
-        or ctypes.util.find_library('magic1')
-        or ctypes.util.find_library('cygmagic-1')
-        or ctypes.util.find_library('libmagic-1')
+        ctypes.util.find_library("magic")
+        or ctypes.util.find_library("magic1")
+        or ctypes.util.find_library("cygmagic-1")
+        or ctypes.util.find_library("libmagic-1")
         # for MSYS2
-        or ctypes.util.find_library('msys-magic-1')
+        or ctypes.util.find_library("msys-magic-1")
     )
     # necessary because find_library returns None if it doesn't find the library
     if dll:
@@ -131,28 +132,29 @@ def load_lib_failover():
 
     if not (libmagic and libmagic._name):
         windows_dlls = [
-            'magic1.dll',
-            'cygmagic-1.dll',
-            'libmagic-1.dll',
-            'msys-magic-1.dll',
+            "magic1.dll",
+            "cygmagic-1.dll",
+            "libmagic-1.dll",
+            "msys-magic-1.dll",
         ]
         platform_to_lib = {
-            'darwin': (
+            "darwin": (
                 [
-                    '/opt/local/lib/libmagic.dylib',
-                    '/usr/local/lib/libmagic.dylib',
-                ] +
+                    "/opt/local/lib/libmagic.dylib",
+                    "/usr/local/lib/libmagic.dylib",
+                ]
+                +
                 # Assumes there will only be one version installed when using brew
-                glob.glob('/usr/local/Cellar/libmagic/*/lib/libmagic.dylib') +
-                glob.glob('/opt/homebrew/Cellar/libmagic/*/lib/libmagic.dylib')
+                glob.glob("/usr/local/Cellar/libmagic/*/lib/libmagic.dylib")
+                + glob.glob("/opt/homebrew/Cellar/libmagic/*/lib/libmagic.dylib")
             ),
-            'win32': windows_dlls,
-            'cygwin': windows_dlls,
-            'linux': ['libmagic.so.1'],
+            "win32": windows_dlls,
+            "cygwin": windows_dlls,
+            "linux": ["libmagic.so.1"],
         }
         # fallback for some Linuxes (e.g. Alpine) where library search does not
         # work # flake8:noqa
-        platform = 'linux' if sys.platform.startswith('linux') else sys.platform
+        platform = "linux" if sys.platform.startswith("linux") else sys.platform
         for dll in platform_to_lib.get(platform, []):
             try:
                 libmagic = ctypes.CDLL(dll)
@@ -179,49 +181,49 @@ def load_lib():
     dll_loc = os.environ.get(TYPECODE_LIBMAGIC_PATH_ENVVAR)
 
     if TRACE and dll_loc:
-        logger_debug('load_lib:', 'got environ magic location:', dll_loc)
+        logger_debug("load_lib:", "got environ magic location:", dll_loc)
 
     # try a plugin-provided path second
     if not dll_loc:
         dll_loc = get_location(TYPECODE_LIBMAGIC_DLL)
 
         if TRACE and dll_loc:
-            logger_debug('load_lib:', 'got plugin magic location:', dll_loc)
+            logger_debug("load_lib:", "got plugin magic location:", dll_loc)
 
     # try well known locations
     if not dll_loc:
         failover_lib = load_lib_failover()
         if failover_lib:
             warnings.warn(
-                'System libmagic found in typical location is used. '
-                'Install instead a typecode-libmagic plugin for best support.'
+                "System libmagic found in typical location is used. "
+                "Install instead a typecode-libmagic plugin for best support."
             )
             return failover_lib
 
     # try the PATH
     if not dll_loc:
-        dll = 'libmagic.dll' if on_windows else 'libmagic.so'
+        dll = "libmagic.dll" if on_windows else "libmagic.so"
         dll_loc = command.find_in_path(dll)
 
         if dll_loc:
             warnings.warn(
-                'libmagic found in the PATH. '
-                'Install instead a typecode-libmagic plugin for best support.'
+                "libmagic found in the PATH. "
+                "Install instead a typecode-libmagic plugin for best support."
             )
 
         if TRACE and dll_loc:
-            logger_debug('load_lib:', 'got path magic location:', dll_loc)
+            logger_debug("load_lib:", "got path magic location:", dll_loc)
 
     if not dll_loc or not os.path.isfile(dll_loc):
         raise NoMagicLibError(
-            'CRITICAL: libmagic DLL and its magic database are not installed. '
-            'Unable to continue: you need to install a valid typecode-libmagic '
-            'plugin with a valid and proper libmagic and magic DB available.\n'
-            f'OR set the {TYPECODE_LIBMAGIC_PATH_ENVVAR} and '
-            f'{TYPECODE_LIBMAGIC_DB_PATH_ENVVAR} environment variables.\n'
-            f'OR install libmagic in typical common locations.\n'
-            f'OR have a libmagic in the system PATH.\n'
-    )
+            "CRITICAL: libmagic DLL and its magic database are not installed. "
+            "Unable to continue: you need to install a valid typecode-libmagic "
+            "plugin with a valid and proper libmagic and magic DB available.\n"
+            f"OR set the {TYPECODE_LIBMAGIC_PATH_ENVVAR} and "
+            f"{TYPECODE_LIBMAGIC_DB_PATH_ENVVAR} environment variables.\n"
+            f"OR install libmagic in typical common locations.\n"
+            f"OR have a libmagic in the system PATH.\n"
+        )
     return command.load_shared_library(dll_loc)
 
 
@@ -242,36 +244,36 @@ def get_magicdb_location(_cache=[]):
     magicdb_loc = os.environ.get(TYPECODE_LIBMAGIC_DB_PATH_ENVVAR)
 
     if TRACE and magicdb_loc:
-        logger_debug('get_magicdb_location:', 'got environ magicdb location:', magicdb_loc)
+        logger_debug("get_magicdb_location:", "got environ magicdb location:", magicdb_loc)
 
     # try a plugin-provided path second
     if not magicdb_loc:
         magicdb_loc = get_location(TYPECODE_LIBMAGIC_DB)
 
         if TRACE and magicdb_loc:
-            logger_debug('get_magicdb_location:', 'got plugin magicdb location:', magicdb_loc)
+            logger_debug("get_magicdb_location:", "got plugin magicdb location:", magicdb_loc)
 
     # try the PATH
     if not magicdb_loc:
-        db = 'magic.mgc'
+        db = "magic.mgc"
         magicdb_loc = command.find_in_path(db)
 
         if magicdb_loc:
             warnings.warn(
-                'magicdb found in the PATH. '
-                'Install instead a typecode-libmagic plugin for best support.\n'
-                f'OR set the {TYPECODE_LIBMAGIC_DB_PATH_ENVVAR} environment variable.'
+                "magicdb found in the PATH. "
+                "Install instead a typecode-libmagic plugin for best support.\n"
+                f"OR set the {TYPECODE_LIBMAGIC_DB_PATH_ENVVAR} environment variable."
             )
 
         if TRACE and magicdb_loc:
-            logger_debug('get_magicdb_location:', 'got path magicdb location:', magicdb_loc)
+            logger_debug("get_magicdb_location:", "got path magicdb location:", magicdb_loc)
 
     if not magicdb_loc:
         warnings.warn(
-            'Libmagic magic database not found. '
-            'A default will be used if possible. '
-            'Install instead a typecode-libmagic plugin for best support.\n'
-            f'OR set the {TYPECODE_LIBMAGIC_DB_PATH_ENVVAR} environment variable.'
+            "Libmagic magic database not found. "
+            "A default will be used if possible. "
+            "Install instead a typecode-libmagic plugin for best support.\n"
+            f"OR set the {TYPECODE_LIBMAGIC_DB_PATH_ENVVAR} environment variable."
         )
         return
 
@@ -280,7 +282,7 @@ def get_magicdb_location(_cache=[]):
 
 
 def mime_type(location):
-    """"
+    """ "
     Return the detected mimetype for file at `location` or an empty string if
     nothing found or an error occurred.
     """
@@ -288,11 +290,11 @@ def mime_type(location):
         return _detect(location, DETECT_MIME)
     except:
         # TODO: log errors
-        return ''
+        return ""
 
 
 def encoding(location):
-    """"
+    """ "
     Return the detected encoding for file at `location` or an empty string.
     Raise an exception on errors.
     """
@@ -300,7 +302,7 @@ def encoding(location):
 
 
 def _detect(location, flags):
-    """"
+    """ "
     Return the detected type using `flags` of file at `location` or an empty
     string. Raise an exception on errors.
     """
@@ -310,9 +312,9 @@ def _detect(location, flags):
         detector = Detector(flags=flags)
         detectors[flags] = detector
     val = detector.get(location)
-    val = val or ''
-    val = val.decode('ascii', 'ignore').strip()
-    return ' '.join(val.split())
+    val = val or ""
+    val = val.decode("ascii", "ignore").strip()
+    return " ".join(val.split())
 
 
 class MagicException(Exception):
@@ -320,7 +322,6 @@ class MagicException(Exception):
 
 
 class Detector(object):
-
     def __init__(self, flags, magic_db_location=None):
         """
         Create a new libmagic detector.
@@ -349,7 +350,7 @@ class Detector(object):
         assert location
         try:
             # first use the path as is
-            return  _magic_file(self.cookie, location)
+            return _magic_file(self.cookie, location)
         except:
             # then try to get a utf-8 encoded path: Rationale:
             # https://docs.python.org/2/library/ctypes.html#ctypes.set_conversion_mode ctypes
@@ -358,10 +359,10 @@ class Detector(object):
             # anymore by libmagic in some cases.
             try:
                 uloc = os.fsencode(location)
-                return  _magic_file(self.cookie, uloc)
+                return _magic_file(self.cookie, uloc)
             except:
                 # if all fails, read the start of the file instead
-                with open(location, 'rb') as fd:
+                with open(location, "rb") as fd:
                     buf = fd.read(16384)
                 return _magic_buffer(self.cookie, buf, len(buf))
 
@@ -393,10 +394,8 @@ def check_error(result, func, args):  # NOQA
     if (
         result is None
         or (is_int and result < 0)
-        or (
-            is_bytes
-            and str(result, encoding='utf-8', errors='ignore').startswith('cannot open'))
-        or (is_text and result.startswith('cannot open'))
+        or (is_bytes and str(result, encoding="utf-8", errors="ignore").startswith("cannot open"))
+        or (is_text and result.startswith("cannot open"))
     ):
         err = _magic_error(args[0])
         raise MagicException(err)
